import React from 'react';
import MapView, { Marker, Callout } from 'react-native-maps';
import GeoJSON from 'geojson';
import Supercluster from 'supercluster';
import { View, Text, StyleSheet } from 'react-native';

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var styles = /*#__PURE__*/StyleSheet.create({
  outer: {
    width: 40,
    height: 40,
    borderRadius: 40 / 2,
    justifyContent: 'center',
    alignItems: 'center'
  },
  inner: {
    width: 30,
    height: 30,
    borderRadius: 30 / 2,
    justifyContent: 'center',
    alignItems: 'center'
  },
  text: {
    fontSize: 12,
    color: 'white'
  }
});
var Cluster = function Cluster(_ref) {
  var item = _ref.item,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'black' : _ref$color,
      props = _objectWithoutPropertiesLoose(_ref, ["item", "color"]);

  var point_count = item.properties.point_count;
  var _item$geometry$coordi = item.geometry.coordinates,
      latitude = _item$geometry$coordi[0],
      longitude = _item$geometry$coordi[1];
  return React.createElement(Marker, Object.assign({
    coordinate: {
      latitude: latitude,
      longitude: longitude
    },
    anchor: {
      x: 0.5,
      y: 0.5
    }
  }, props), React.createElement(View, {
    style: [styles.outer, {
      backgroundColor: "rgba(" + color + ", 0.25)"
    }]
  }, React.createElement(View, {
    style: [styles.inner, {
      backgroundColor: "rgb(" + color + ")"
    }]
  }, React.createElement(Text, {
    style: styles.text
  }, point_count))));
};

var styles$1 = /*#__PURE__*/StyleSheet.create({
  marker: {
    position: 'relative',
    justifyContent: 'center',
    alignItems: 'center',
    padding: 4,
    borderRadius: 2
  },
  markerText: {
    fontSize: 12,
    color: 'white'
  },
  pointer: {
    width: 10,
    height: 10,
    alignSelf: 'center',
    transform: [{
      rotate: '45deg'
    }],
    top: -6
  }
});
var CustomMarker = function CustomMarker(_ref) {
  var item = _ref.item,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'black' : _ref$color,
      children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["item", "color", "children"]);

  var _item$properties = item.properties,
      price = _item$properties.price,
      currency = _item$properties.currency;
  var _item$geometry$coordi = item.geometry.coordinates,
      latitude = _item$geometry$coordi[0],
      longitude = _item$geometry$coordi[1];
  return React.createElement(Marker, Object.assign({
    coordinate: {
      latitude: latitude,
      longitude: longitude
    },
    anchor: {
      x: 0.5,
      y: 0.75
    },
    calloutOffset: {
      x: 100,
      y: 50
    },
    calloutAnchor: {
      x: 0.5,
      y: 0
    },
    opacity: 0.8
  }, props), React.createElement(View, {
    style: [styles$1.marker, {
      backgroundColor: color
    }]
  }, React.createElement(Text, {
    numberOfLines: 1,
    style: [styles$1.markerText]
  }, currency, price)), React.createElement(View, {
    style: [styles$1.pointer, {
      backgroundColor: color
    }]
  }), React.createElement(Callout, {
    tooltip: true,
    style: {
      flexDirection: 'column'
    }
  }, children));
};

var INITIAL_REGION = {
  latitude: 55.676098,
  longitude: 12.568337,
  latitudeDelta: 0.0922,
  longitudeDelta: 0.0421
};
var Map = function Map(_ref) {
  var children = _ref.children,
      data = _ref.data,
      _ref$radius = _ref.radius,
      radius = _ref$radius === void 0 ? 40 : _ref$radius,
      _ref$minZoom = _ref.minZoom,
      minZoom = _ref$minZoom === void 0 ? 0 : _ref$minZoom,
      _ref$maxZoom = _ref.maxZoom,
      maxZoom = _ref$maxZoom === void 0 ? 16 : _ref$maxZoom,
      _ref$extent = _ref.extent,
      extent = _ref$extent === void 0 ? 512 : _ref$extent,
      _ref$nodeSize = _ref.nodeSize,
      nodeSize = _ref$nodeSize === void 0 ? 64 : _ref$nodeSize,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "data", "radius", "minZoom", "maxZoom", "extent", "nodeSize"]);

  var _React$useState = React.useState([]),
      clusters = _React$useState[0],
      setClusters = _React$useState[1];

  var _React$useState2 = React.useState({
    northEast: {
      latitude: INITIAL_REGION.latitude + INITIAL_REGION.latitudeDelta / 2,
      longitude: INITIAL_REGION.longitude + INITIAL_REGION.longitudeDelta / 2
    },
    southWest: {
      latitude: INITIAL_REGION.latitude - INITIAL_REGION.latitudeDelta / 2,
      longitude: INITIAL_REGION.longitude - INITIAL_REGION.longitudeDelta / 2
    },
    southEast: {
      latitude: INITIAL_REGION.latitude + INITIAL_REGION.latitudeDelta / 2,
      longitude: INITIAL_REGION.longitude - INITIAL_REGION.longitudeDelta / 2
    },
    northWest: {
      latitude: INITIAL_REGION.latitude - INITIAL_REGION.latitudeDelta / 2,
      longitude: INITIAL_REGION.longitude + INITIAL_REGION.longitudeDelta / 2
    }
  }),
      area = _React$useState2[0],
      setArea = _React$useState2[1];

  var clusterIndex = new Supercluster({
    radius: radius,
    minZoom: minZoom,
    maxZoom: maxZoom,
    extent: extent,
    nodeSize: nodeSize
  });

  var createCluster = function createCluster(data) {
    var items = GeoJSON.parse(data, {
      Point: ['latitude', 'longitude']
    });
    clusterIndex.load(items.features);
    return clusterIndex;
  };

  var getZoomLevel = function getZoomLevel(latitudeDelta) {
    return Math.round(Math.log(360 / latitudeDelta) / Math.LN2);
  };

  var createRegions = function createRegions(region) {
    var items = createCluster(data).getClusters([area.southWest.longitude, area.southWest.latitude, area.northEast.longitude, area.northEast.latitude], getZoomLevel(region.latitudeDelta));
    setClusters(items);
  };

  var _onRegionChangeComplete = function onRegionChangeComplete(region) {
    setArea({
      northEast: {
        latitude: region.latitude + region.latitudeDelta / 2,
        longitude: region.longitude + region.longitudeDelta / 2
      },
      southWest: {
        latitude: region.latitude - region.latitudeDelta / 2,
        longitude: region.longitude - region.longitudeDelta / 2
      },
      southEast: {
        latitude: region.latitude + region.latitudeDelta / 2,
        longitude: region.longitude - region.longitudeDelta / 2
      },
      northWest: {
        latitude: region.latitude - region.latitudeDelta / 2,
        longitude: region.longitude + region.longitudeDelta / 2
      }
    });
    createRegions(region);
  };

  return React.createElement(MapView, Object.assign({
    initialRegion: INITIAL_REGION,
    onRegionChangeComplete: function onRegionChangeComplete(newRegion) {
      return _onRegionChangeComplete(newRegion);
    }
  }, props), clusters.map(function (item, index) {
    return item.properties.cluster ? React.createElement(Cluster, {
      key: index,
      item: item
    }) : React.createElement(CustomMarker, {
      key: index,
      item: item
    });
  }), children);
};

export default Map;
export { Cluster, CustomMarker, Map };
//# sourceMappingURL=react-native-maps-clusters.esm.js.map
